#ifndef FILTER_H
#define FILTER_H

/**
 * @brief Adds a custom filter
 *
 * The pattern, describing a POSIX regular expression, is used to determine
 * network traffic belonging to a service.
 *
 * @param pattern Pattern to match network traffic againt
 * @param service Associated service (protocol) name
 */
void filter_setup(const char *pattern, const char *service);
/*NO EXTERNAL REFERENCE NEEDED!*/

/**
 * @brief Tries to match against a filter
 *
 * @param extract The data used for matching
 *
 * @return 1 if matched, 0 if not matched
 */
int filter_tell(const char *extract);

/**
 * @brief Tries to match binary data against a filter
 *
 * @param array The binary data used for matching
 * @param length Length of the binary data
 *
 * @return 1 if matched, 0 if not matched
 */
int filter_tellbinary(unsigned char *array, int length);

/**
 * @brief Setup all filters
 *
 * This sets up all known filters such as for http, postgres and others.
 */
/*void filter_setupall(void);*/
/*NO EXTERNAL REFERENCE NEEDED!*/

#endif

