#ifndef IPBAN_H
#define IPBAN_H

/**
 * @brief Add an IP address or IP range to be banned.
 * 
 * Add a literal IP address or a range to the list of banned IP addresses.
 * Note that upon removal of those, the same string must be specified again.
 * The internal buffer is initialized automatically if this function is called
 * the first time.
 *
 * @param iprange: IP address or range in a format like "192.168.0.2" or
 * "192.168.0.0/24" or "192.168.0.xxx or "192.168.0."
 * 
 * @return 0 for success, 1 for duplicate entry, -1 for error
 */
int ipban_add(const char *iprange);

/**
 * @brief Remove an IP address or IP range
 *
 * This function removes a previously added IP address or range from the
 * internal list.
 *
 * @param iprange: See @see ipban_add
 *
 * @return 0 for success, 1 for entry not found, -1 for error
 */
int ipban_remove(const char *iprange);

/**
 * @brief Check whether an IP address is banned or not
 *
 * Takes a single IP address and matches it against the internal list of banned
 * ones.
 *
 * @param ipaddress A single IP address in the format "192.168.0.45"
 *
 * @return 0 for not banned, 1 for banned, -1 for error
 */
int ipban_check(const char *ipaddress);

#endif

