/* MoreBalance includes */
#include "sys.h"

/* System includes */
#include <netdb.h>
#include <netinet/in.h>
#include <stdlib.h>
#include <string.h>

#include <stdio.h>

/* Return the port number of this service */
int sys_port(const char *service)
{
	struct servent *serv;
	char *token, *tmp;
	int port;

	if(!service) return 0;

	tmp = strdup(service);
	token = strtok(tmp, ":");

	if(token)
	{
		serv = getservbyname(token, "tcp");

		if(serv)
		{
			if(!serv->s_port) port = 0;
			else port = ntohs(serv->s_port);
		}
		else port = atoi(token);
	}
	else port = 0;

	free(tmp);

	return port;
}

int sys_portoptions(const char *service)
{
	char *token, *tmp;
	int options;

	options = 0;

	tmp = strdup(service);
	token = strtok(tmp, ":");
	while(token)
	{
		token = strtok(NULL, ":");
		if(token)
		{
			if(!strcmp(token, "tls")) options |= opt_tls;
			if(!strcmp(token, "tlsv1")) options |= opt_tls;
			if(!strcmp(token, "tcp")) options |= opt_tcp;
			if(!strcmp(token, "udp")) options |= opt_udp;
			if(!strcmp(token, "local")) options |= opt_local;
		}
	}
	free(tmp);

	return options;
}

/* Checks whether a host is local or remote */
int sys_local(const char *host)
{
	struct hostent *h;
	unsigned int a;
	int i;

	if(!host) return 0;
	/*if(!strcmp(host, "localhost")) return 1;*/

	h = gethostbyname(host);
	if(h)
	{
		for(i = 0; h->h_addr_list[i]; i++)
		{
			a = ntohl(*h->h_addr_list[i]);
			if((((a & 0xFF000000) >> 24) == 127)
			&& (((a & 0x00FF0000) >> 16) == 0)
			&& (((a & 0x0000FF00) >> 8) == 0)
			&& (((a & 0x00000000)) == 0)) return 1;
		}
	}
	else return -1;

	return 0;
}

